/****************************************************************************

    This file is part of The Newtonator soft synth.

    Copyright (C) 2010-2011 Michael Bechard <mbechard@users.sourceforge.net>

    The Newtonator is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Newtonator is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with The Newtonator.  If not, see <http://www.gnu.org/licenses/>.

****************************************************************************/

#ifndef INEWTSETTINGS_H_INCLUDED
#define INEWTSETTINGS_H_INCLUDED

#include "VariSource.h"

enum CeilingBehavEnum
{
    ExtClip,
    IntClip,
    Bounce,
    BounceMirror,
    Unknown
};

class INewtSettings
{
    public:
    //Main Newtonator settings
	virtual stk::StkFloat getGravityScale(unsigned int chan) = 0;
	virtual CeilingBehavEnum getCeilingBehavior(unsigned int chan) = 0;
	virtual stk::StkFloat getVelocReset(unsigned int chan) = 0;
	virtual bool getStereo() = 0;
	virtual stk::StkFloat getVelocDelay(unsigned int chan) = 0;
	virtual stk::StkFloat getCeilingBounce(unsigned int chan) = 0;
	virtual stk::StkFloat getDeadZone(unsigned int chan) = 0;
	#ifdef INCLUDE_EXT_INPUTS
	virtual float* getFloorExtInput(unsigned int chan) = 0;
	virtual float* getGModExtInput(unsigned int chan) = 0;
	#endif
	virtual stk::StkFloat getWobbleA(unsigned int chan) = 0;
	virtual stk::StkFloat getWobbleB(unsigned int chan) = 0;
	virtual stk::StkFloat getWobbleScale(unsigned int chan) = 0;
	virtual stk::StkFloat getWobbleTimbre(unsigned int chan) = 0;
	virtual stk::StkFloat getVelocRM(unsigned int chan) = 0;
	virtual stk::StkFloat getVelocSaH(unsigned int chan) = 0;
	virtual stk::StkFloat getAmp(unsigned int chan) = 0;

	//Amp Env settings
    virtual stk::StkFloat getAmpAttack(unsigned int chan) = 0;
	virtual stk::StkFloat getAmpDecay(unsigned int chan) = 0;
	virtual stk::StkFloat getAmpSustain(unsigned int chan) = 0;
	virtual stk::StkFloat getAmpRelease(unsigned int chan) = 0;

	//Gravity Modulator Settings
	virtual stk::StkFloat getGModDepth(unsigned int chan) = 0;
	virtual stk::StkFloat getGModAttack(unsigned int chan) = 0;
	virtual stk::StkFloat getGModDecay(unsigned int chan) = 0;
	virtual stk::StkFloat getGModSustain(unsigned int chan) = 0;
	virtual stk::StkFloat getGModRelease(unsigned int chan) = 0;
	virtual stk::StkFloat getGModFrequency(unsigned int chan) = 0;
	virtual VariSource::Type getGModType(unsigned int chan) = 0;
	virtual bool getGModEnv(unsigned int chan) = 0;
	virtual stk::StkFloat getGModFreqDrift(unsigned int chan) = 0;
	virtual stk::StkFloat getGModFreqDiv(unsigned int chan) = 0;
	virtual bool getGModFollowFreq(unsigned int chan) = 0;
	virtual stk::StkFloat getGModDCOffset(unsigned int chan) = 0;

    protected:
	virtual ~INewtSettings() {}
};

#endif //INEWTSETTINGS_H_INCLUDED
