/****************************************************************************
    
    This file is part of The Newtonator soft synth.

    Copyright (C) 2010-2011 Michael Bechard <mbechard@users.sourceforge.net>

    The Newtonator is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Newtonator is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with The Newtonator.  If not, see <http://www.gnu.org/licenses/>.

****************************************************************************/

#ifndef NEWTSCALARWIDGET_H
#define NEWTSCALARWIDGET_H

#include <gtkmm/box.h>
#include <gtkmm/spinbutton.h>
#include <gtkmm/drawingarea.h>
#include <cairomm/context.h>
#include <glib.h>
#include <stk/Stk.h>
#include "applewidget.h"
#include "control_enum.h"

class NewtParentWidget;

class NewtScalarWidget : public Gtk::HBox
{
    public:
        NewtScalarWidget(Glib::ustring label, double min, double max, double def, NewtParentWidget* parent, ControlEnum ctrlID, unsigned int precision = 3, double climbRate = .001);
        virtual ~NewtScalarWidget();

        inline double GetValue() const { return m_value; }
        inline double GetZeroToOneValue() const { return (m_value - m_min) / (m_max - m_min); }
        void SetValue(double val);
        inline double GetMin() const { return m_min; }
        inline double GetMax() const { return m_max; }
        inline ControlEnum GetCtrlID() const { return m_ctrlID; }

        typedef sigc::signal<void> type_signal_value_changed;
        inline type_signal_value_changed signal_value_changed() { return m_valueChanged; }

    protected:
        void InitSpin();
        void InitApple();
        void on_spin_value_changed();
        void on_value_should_change(ControlEnum ctrl, stk::StkFloat val);
        virtual void forall_vfunc(gboolean include_internals, GtkCallback callback, gpointer callback_data);

    private:

        double m_value;
        double m_min;
        double m_max;
        unsigned int m_precision;
        double m_climbRate;
        Gtk::SpinButton m_spin;
        Gtk::Label m_label;
        AppleWidget m_apple;
        type_signal_value_changed m_valueChanged;
        ControlEnum m_ctrlID;
        NewtParentWidget* m_parent;
};

#endif // NEWTSCALARWIDGET_H
